/*
 *******************************************************************
 *              TMark favorites plugin for TVBrowser               *
 *                                                                 *
 * Copyright (C) 2006 Tomas Schackert.                             *
 * Contact koumori@web.de                                          *
 *******************************************************************

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation, in version 2 of the License.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
 
 You should have received a copy of the GNU General Public License
 along with this program, in a file called LICENSE in the top
 directory of the distribution; if not, write to 
 the Free Software Foundation, Inc., 59 Temple Place, Suite 330, 
 Boston, MA  02111-1307  USA
 
 *******************************************************************/

package tmarkplugin.properties;

import java.awt.Font;
import java.util.Enumeration;
import java.util.Map;
import java.util.Properties;

/**
 * @author Tomas
 *
 */
public class FilePropertySource extends PropertySource {
	private Properties props;
	public FilePropertySource(Properties props){
		this.props=props;
	}
	/** dynamic access to data types*/
	

	public Font getFontProperty(String basekey, Font defaultvalue) {
		if (props==null) return defaultvalue;
		int style=(defaultvalue!=null)?defaultvalue.getStyle():0;
		String name=(defaultvalue!=null)?defaultvalue.getName():"";
		int size=(defaultvalue!=null)?defaultvalue.getSize():8;

		style=getIntProperty(basekey+".style",style);
		name=getProperty(basekey+".name",name);
		size=getIntProperty(basekey+".size",size);
		return new Font(name, style, size);
	}
	public void setFontProperty(String basekey, Font value) {
		if (props==null) return;
		setIntProperty(basekey+".style",value.getStyle());
		setProperty(basekey+".name",value.getName());
		setIntProperty(basekey+".size",value.getSize());
	}
	public String setProperty(String key, String value) {
		if (props==null) return null;
		if (value==null){
			return (String)props.remove(key);
		}else{
			return (String)props.setProperty(key, value);
		}
	}
	public String getProperty(String key, String defaultvalue) {
		if (props==null) return defaultvalue;
		String result=props.getProperty(key);
		if (result==null)return defaultvalue;
		return result;
	}

	public Enumeration getPropertyKeys(){
		if (props!=null)return props.keys();
		else return new Enumeration(){
			public boolean hasMoreElements() {
				return false;
			}
			public Object nextElement() {
				return null;
			}
		};
	}
	/**
	 * @return
	 */
	public Map getProperties() {
		return this.props;
	}


}
